# Jobs

Types:

```python
from rainbows.types import (
    JobGetResponse,
    JobRetrieveTermBasedResponse,
    JobUpsertResponse,
    JobUpsertFromJsonlResponse,
)
```

Methods:

- <code title="post /jobs/get">client.jobs.<a href="./src/rainbows/resources/jobs.py">get</a>(\*\*<a href="src/rainbows/types/job_get_params.py">params</a>) -> <a href="./src/rainbows/types/job_get_response.py">JobGetResponse</a></code>
- <code title="post /jobs/retrieve_term_based">client.jobs.<a href="./src/rainbows/resources/jobs.py">retrieve_term_based</a>(\*\*<a href="src/rainbows/types/job_retrieve_term_based_params.py">params</a>) -> <a href="./src/rainbows/types/job_retrieve_term_based_response.py">JobRetrieveTermBasedResponse</a></code>
- <code title="post /jobs/upsert">client.jobs.<a href="./src/rainbows/resources/jobs.py">upsert</a>(\*\*<a href="src/rainbows/types/job_upsert_params.py">params</a>) -> <a href="./src/rainbows/types/job_upsert_response.py">JobUpsertResponse</a></code>
- <code title="post /jobs/upsert_from_jsonl">client.jobs.<a href="./src/rainbows/resources/jobs.py">upsert_from_jsonl</a>(\*\*<a href="src/rainbows/types/job_upsert_from_jsonl_params.py">params</a>) -> <a href="./src/rainbows/types/job_upsert_from_jsonl_response.py">JobUpsertFromJsonlResponse</a></code>
